info = {
    "name": "wae",
    "date_order": "YMD",
    "january": [
        "jen",
        "jenner"
    ],
    "february": [
        "hor",
        "hornig"
    ],
    "march": [
        "mär",
        "märze"
    ],
    "april": [
        "abr",
        "abrille"
    ],
    "may": [
        "mei",
        "meije"
    ],
    "june": [
        "brá",
        "bráčet"
    ],
    "july": [
        "hei",
        "heiwet"
    ],
    "august": [
        "öig",
        "öigšte"
    ],
    "september": [
        "her",
        "herbštmánet"
    ],
    "october": [
        "wím",
        "wímánet"
    ],
    "november": [
        "win",
        "wintermánet"
    ],
    "december": [
        "chr",
        "chrištmánet"
    ],
    "monday": [
        "män",
        "mäntag"
    ],
    "tuesday": [
        "ziš",
        "zištag"
    ],
    "wednesday": [
        "mit",
        "mittwuč"
    ],
    "thursday": [
        "fró",
        "fróntag"
    ],
    "friday": [
        "fri",
        "fritag"
    ],
    "saturday": [
        "sam",
        "samštag"
    ],
    "sunday": [
        "sun",
        "sunntag"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jár"
    ],
    "month": [
        "mánet"
    ],
    "week": [
        "wuča"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "mínütta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "hitte"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "gešter"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "móre"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "vor (\\d+) tag",
            "vor (\\d+) täg"
        ],
        "\\1 hour ago": [
            "vor (\\d+) stund",
            "vor (\\d+) stunde"
        ],
        "\\1 minute ago": [
            "vor (\\d+) minüta",
            "vor (\\d+) minüte"
        ],
        "\\1 month ago": [
            "vor (\\d+) mánet"
        ],
        "\\1 second ago": [
            "vor (\\d+) sekund",
            "vor (\\d+) sekunde"
        ],
        "\\1 week ago": [
            "cor (\\d+) wučä",
            "vor (\\d+) wuča"
        ],
        "\\1 year ago": [
            "cor (\\d+) jár",
            "vor (\\d+) jár"
        ],
        "in \\1 day": [
            "i (\\d+) tag",
            "i (\\d+) täg"
        ],
        "in \\1 hour": [
            "i (\\d+) stund",
            "i (\\d+) stunde"
        ],
        "in \\1 minute": [
            "i (\\d+) minüta",
            "i (\\d+) minüte"
        ],
        "in \\1 month": [
            "i (\\d+) mánet"
        ],
        "in \\1 second": [
            "i (\\d+) sekund",
            "i (\\d+) sekunde"
        ],
        "in \\1 week": [
            "i (\\d+) wuča",
            "i (\\d+) wučä"
        ],
        "in \\1 year": [
            "i (\\d+) jár"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
